#!/bin/bash

UBT_PACKAGE_NAME="exagear_*-1_armhf.deb"
GUEST_IMAGE_PACKAGE_NAME="exagear-guest-ubuntu-1204lts_*_all.deb"
PK_FILE_NAME="pk-*.key"

function file_exists {
    stat $1 &> /dev/null
}

uid=$(id -u)
if [ "$uid" != "0" ] ; then
    echo "Must be root"
    exit 1
fi

if ! file_exists "$UBT_PACKAGE_NAME" ; then
    echo "Put the translator package to the current directory."
    echo "The package is named ${UBT_PACKAGE_NAME/\*/NNNN}."
    exit 1
fi

if ! file_exists "$GUEST_IMAGE_PACKAGE_NAME" ; then
    echo "Put the guest image package to the current directory."
    echo "The package is named ${GUEST_IMAGE_PACKAGE_NAME/\*/N}."
    exit 1
fi

if ! file_exists "$PK_FILE_NAME" ; then
    echo "Put a primary key file to the current directory."
    echo "Primary key files are named ${PK_FILE_NAME/\*/NNNNNN}"
    exit 1
fi

echo "Installing prerequisites..."
#apt-get update
for prereq in bash coreutils findutils realpath curl binfmt-support ; do
#    apt-get -y install $prereq || exit 1
    opkg list-installed|grep $prereq
done

echo "Installing the binary translator..."
#dpkg -i $UBT_PACKAGE_NAME || exit 1
ar p $UBT_PACKAGE_NAME data.tar.gz | tar zx

echo "Installing the guest image..."
#dpkg -i $GUEST_IMAGE_PACKAGE_NAME || exit 1
ar p $GUEST_IMAGE_PACKAGE_NAME data.tar.gz | tar zx

cp etc/*.conf /etc/
cp usr/bin/* /usr/bin/
ln -s $(pwd)/opt /

echo "Installing the primary key..."
cp $PK_FILE_NAME /opt/exagear/lic/ || exit 1

echo "Activating the copy of ExaGear..."
/opt/exagear/bin/actool || exit 1

echo "Done!"

echo "Fixing"
vpaths_list=`ls /opt/exagear/images/*/.exagear/vpaths-list`
#opaths_list=`ls /opt/exagear/images/*/.exagear/opaths-list`
sed s/\\/etc\\/resolvconf\\/// -i $vpaths_list
sed s/\\/etc\\/ldap\\/// -i $vpaths_list
sed s/\\/etc\\/fstab.d\\/// -i $vpaths_list
sed s/\\/etc\\/ca-certificates\\/// -i $vpaths_list
sed s/\\/etc\\/modprobe.d\\/// -i $vpaths_list
sed s/\\/etc\\/pulse\\/// -i $vpaths_list
sed s/\\/usr\\/share\\/alsa-base\\/// -i $vpaths_list
sed s/\\/root\\/// -i $vpaths_list
sed s/\\/tmp\\/// -i $vpaths_list
#chmod a+w /opt/exagear/images/*/tmp
sed s/\\/run\\/// -i $vpaths_list
sed s/\\/var\\/log\\/// -i $vpaths_list
echo /var/volatile/ >> $vpaths_list

vpath=`ls -d /opt/exagear/images/*`
mkdir $vpath/var/volatile
rm -rf $vpath/tmp
ln -s /var/volatile/tmp $vpath/tmp
rm -rf $vpath/run
ln -s /var/volatile/run $vpath/run
rm -rf $vpath/var/log
ln -s /var/volatile/log $vpath/var/log

rm $vpath/var/lib/dpkg/statoverride
